@@ -1,15 +1,18 @@
 package Mojolicious::Plugin::FeedReader;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 use Mojo::Util qw(decode trim);
 use Mojo::File;
 use Mojo::DOM;
 use Mojo::IOLoop;
 use HTTP::Date;
+use Mojo::UserAgent;
 use Carp qw(carp croak);
 use Scalar::Util qw(blessed);
 
+has ua => sub { Mojo::UserAgent->new };
+
 our @time_fields
   = (qw(pubDate published created issued updated modified dc\:date));
 our %is_time_field = map { $_ => 1 } @time_fields;
@@ -26,12 +29,15 @@ our $default_charset = 'UTF-8';
 
 sub register {
   my ($self, $app) = @_;
+
+  $self->ua( $app->ua );
+
   foreach my $method (
     qw( find_feeds parse_rss parse_opml ))
   {
-    $app->helper($method => \&{$method});
+    $app->helper($method => sub { shift; $self->$method(@_) });
   }
-  $app->helper(parse_feed => \&parse_rss);
+  $app->helper(parse_feed => sub { shift; $self->parse_rss(@_) });
 }
 
 sub make_dom {
@@ -60,13 +66,13 @@ sub make_dom {
 }
 
 sub parse_rss {
-  my ($c, $xml, $cb) = @_;
+  my ($self, $xml, $cb) = @_;
   my $charset = undef;
   if (blessed $xml && $xml->isa('Mojo::URL')) {
     # this is the only case where we might go non-blocking:
     if ($cb && ref $cb eq 'CODE') {
       return
-      $c->ua->get(
+      $self->ua->get(
         $xml,
         sub {
           my ($ua, $tx) = @_;
@@ -77,12 +83,12 @@ sub parse_rss {
             my $dom = make_dom(\$body, $charset);
             eval { $feed = parse_rss_dom($dom); };
           }
-          $c->$cb($feed);
+          $cb->($feed);
         }
       );
     }
     else {
-      my $tx = $c->ua->get($xml);
+      my $tx = $self->ua->get($xml);
       if ($tx->success) {
         my $body = $tx->res->body;
         $charset = $tx->res->content->charset;
@@ -325,7 +331,7 @@ sub _find_feed_links {
     unless (@feeds)
     {    # call me crazy, but maybe this is just a feed served as HTML?
       my $body = $res->body;
-      if ($self->parse_feed(\$body)) {
+      if ($self->parse_rss(\$body)) {
         push @feeds, Mojo::URL->new($url)->to_abs;
       }
     }
@@ -475,7 +481,7 @@ If given a callback function as an additional argument, execution will be non-bl
 
   # non-blocking
   $self->parse_feed($url, sub {
-    my ($c, $feed) = @_;
+    my ($feed) = @_;
     $c->render(text => "Feed tagline: " . $feed->{tagline});
   });
 
@@ -555,12 +561,25 @@ Parse an OPML subscriptions file and return the list of feeds as an array of has
 
 Each hashref will contain an array ref in the key 'categories' listing the folders (parent nodes) in the OPML tree the subscription item appears in.
 
+=head1 STAND-ALONE USE
+
+L<Mojolicious::Plugin::FeedReader> can also be used directly, rather than as a plugin:
+
+  use Mojolicious::Plugin::FeedReader;
+  my $fr = Mojolicious::Plugin::FeedReader->new( ua => Mojo::UserAgent->new );
+  my ($feed) = $fr->find_feeds($url);
+  ...
+
+In the future, the feed-parsing code will probably move into its own module.
+
+
 =head1 CREDITS
 
-Some tests adapted from L<Feed::Find> and L<XML:Feed> Feed autodiscovery adapted from L<Feed::Find>.
+Dotan Dimet
 
-Test data (web pages, feeds and excerpts) included in this package is intended for testing purposes only, and is not meant in any way
-to infringe on the rights of the respective authors.
+Mario Domgoergen
+
+Some tests adapted from L<Feed::Find> and L<XML:Feed>, Feed autodiscovery adapted from L<Feed::Find>.
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -569,6 +588,9 @@ Copyright (C) 2014, Dotan Dimet.
 This program is free software, you can redistribute it and/or modify it
 under the terms of the Artistic License version 2.0.
 
+Test data (web pages, feeds and excerpts) included in this package is intended for testing purposes only, and is not meant in any way
+to infringe on the rights of the respective authors.
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>
